@@ -1,6 +1,6 @@
 package Git::Hooks;
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
-$Git::Hooks::VERSION = '2.6.2';
+$Git::Hooks::VERSION = '2.6.3';
 use 5.010;
 use strict;
 use warnings;
@@ -111,7 +111,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 2.6.2
+version 2.6.3
 
 =head1 SYNOPSIS
 
@@ -232,6 +232,10 @@ don't worry. Git::Hooks can drive external hooks very easily.
 
 =head1 USAGE
 
+Please, read the L<Git::Hooks::Tutorial> if you want an easy guide to start
+using the framework. Most probably you can set it up in a few minutes with
+it. Continue on if you want to get deeper in the Documentation.
+
 There are a few simple steps you should do in order to set up
 Git::Hooks so that you can configure it to use some predefined plugins
 or start coding your own hooks.
@@ -1149,6 +1153,8 @@ The following commands may give you an idea as to which commands to use:
 
 =item * L<fortune|https://en.wikipedia.org/wiki/Fortune_(Unix)>
 
+=item * L<FIGlet|http://www.figlet.org/>
+
 =item * L<cowsay|https://en.wikipedia.org/wiki/Cowsay>
 
 =item * C<fortune -s | cowsay>
@@ -1238,7 +1244,7 @@ though.
 
 =over
 
-=item * L<Git::Hooks wiki|https://github.com/gnustavo/Git-Hooks/wiki>
+=item * L<Git::Hooks::Tutorial>
 
 Tutorials for Git users and administrators.
 
