@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckJira;
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages
-$Git::Hooks::CheckJira::VERSION = '2.6.2';
+$Git::Hooks::CheckJira::VERSION = '2.6.3';
 use 5.010;
 use utf8;
 use strict;
@@ -31,8 +31,8 @@ sub _setup_config {
     # Default matchkey for matching default JIRA keys.
     $default->{matchkey}   //= ['\b[A-Z][A-Z]+-\d+\b'];
 
-    $default->{require}    //= [1];
-    $default->{unresolved} //= [1];
+    $default->{require}    //= ['true'];
+    $default->{unresolved} //= ['true'];
 
     return;
 }
@@ -222,6 +222,10 @@ EOS
         # Conjunct all terms in a single JQL expression
         my $JQL = '(' . join(') AND (', @jqls) . ')';
 
+        # Squeeze multiple whitespaces in a single space to make it appear
+        # neatly in error messages.
+        $JQL =~ s/\s{2,}/ /g;
+
         my $issues = _jql_query($git, $JQL);
 
         @issues{keys %$issues} = values %$issues; # cache all matched issues
@@ -236,7 +240,7 @@ The commit @{[$commit->commit]} cites an invalid issue:
 
   @{[$missed_set]}
 
-The issue does not match the JQL expression:
+The issue does not match the following JQL expression:
 
   $JQL
 
@@ -248,7 +252,7 @@ The commit @{[$commit->commit]} cites invalid issues:
 
   @{[$missed_set]}
 
-The issues do not match the JQL expression:
+The issues do not match the following JQL expression:
 
   $JQL
 
@@ -596,7 +600,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 2.6.2
+version 2.6.3
 
 =head1 SYNOPSIS
 
