@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckLog;
 # ABSTRACT: Git::Hooks plugin to enforce commit log policies
-$Git::Hooks::CheckLog::VERSION = '2.6.2';
+$Git::Hooks::CheckLog::VERSION = '2.6.3';
 use 5.010;
 use utf8;
 use strict;
@@ -24,7 +24,7 @@ sub _setup_config {
     $config->{lc $CFG} //= {};
 
     my $default = $config->{lc $CFG};
-    $default->{'title-required'}  //= [1];
+    $default->{'title-required'}  //= ['true'];
     $default->{'title-max-width'} //= [50];
     $default->{'title-period'}    //= ['deny'];
     $default->{'body-max-width'}  //= [72];
@@ -418,7 +418,7 @@ Git::Hooks::CheckLog - Git::Hooks plugin to enforce commit log policies
 
 =head1 VERSION
 
-version 2.6.2
+version 2.6.3
 
 =head1 SYNOPSIS
 
