@@ -1,6 +1,6 @@
 package Git::Repository::Plugin::GitHooks;
 # ABSTRACT: A Git::Repository plugin with some goodies for hook developers
-$Git::Repository::Plugin::GitHooks::VERSION = '2.6.2';
+$Git::Repository::Plugin::GitHooks::VERSION = '2.6.3';
 use parent qw/Git::Repository::Plugin/;
 
 use 5.010;
@@ -584,9 +584,9 @@ sub get_config {
         }
 
         # Set default values for undefined ones.
-        $config{githooks}{externals}       //= [1];
-        $config{githooks}{gerrit}{enabled} //= [1];
-        $config{githooks}{'abort-commit'}  //= [1];
+        $config{githooks}{externals}       //= ['true'];
+        $config{githooks}{gerrit}{enabled} //= ['true'];
+        $config{githooks}{'abort-commit'}  //= ['true'];
 
         $git->{_plugin_githooks}{config} = \%config;
     }
@@ -1254,7 +1254,7 @@ Git::Repository::Plugin::GitHooks - A Git::Repository plugin with some goodies f
 
 =head1 VERSION
 
-version 2.6.2
+version 2.6.3
 
 =head1 SYNOPSIS
 
